``cloudi_api_python``
=====================

|Build Status| |PyPI Package Version|

Python `CloudI API <https://cloudi.org/api.html#1_Intro>`__


Author
------

Michael Truog (mjtruog at protonmail dot com)

License
-------

MIT License

.. |Build Status| image:: https://travis-ci.org/CloudI/cloudi_api_python.png
   :target: https://travis-ci.org/CloudI/cloudi_api_python
.. |PyPI Package Version| image:: https://img.shields.io/pypi/v/cloudi.svg?maxAge=2592000
   :target: https://pypi.python.org/pypi/cloudi/
